## LtlOpt 1.0.0
A Matlab toolbox for the optimal control of high-dimensional, nonlinear
robotic systems with linear temporal logic (LTL) specifications.

### Dependencies
#### Core
- Matlab 2012a+: http://www.mathworks.com/products/matlab/
- MPT 2.6.3: http://control.ee.ethz.ch/~mpt/2/downloads/ for polytope operations
- YALMIP: http://users.isy.liu.se/johanl/yalmip/ for optimization interface and parser.

#### Required for automaton-guided approach: 
- ltl2ba: http://www.lsv.ens-cachan.fr/~gastin/ltl2ba/download.php
- MatlabBGL: http://www.mathworks.com/matlabcentral/fileexchange/10922-matlabbgl


### Installation Instructions
LtlOpt 1.0 has been tested on Mac OSX 10.6 using Matlab R2012a, MPT 2.6.3, 
and YALMIP 20130628.

1. Install MPT 2.6.3 (http://control.ee.ethz.ch/~mpt/2/downloads/)   
2. Install YALMIP (http://users.isy.liu.se/johanl/yalmip/)   
3. Install at least one MILP/MIQP solver:   
    * CPLEX (http://www-01.ibm.com/software/commerce/optimization/cplex-optimizer/)
    * Gurobi (http://www.gurobi.com/)
    * GLPK (http://www.gnu.org/software/glpk/)
4. Remove any old version of LtlOpt   
5. Unzip ltlOpt.zip   
6. Add the following paths in your MATLAB path:   
 * /ltlopt/automaton
 * /ltlopt/env
 * /ltlopt/sys
 * /ltlopt/milp
 * /ltlopt/utils
7. Restart Matlab   

### Hello World
Run either mainPt2Pt.m, mainLTL.m, or mainGuided.m. Configuration parameters can
be modified in initParams.m. New environments or system dynamics can be created
as shown in the /env/ and /sys/ folders.   
- /automaton/mainGuided.m: Run to use the automaton-guided planner.   
- /milp/mainLTL.m: Run to use the MILP planner.   
- /milp/mainPt2Pt.m: Run to do classical reach-avoid or point-to-point (region) planning to a goal. 
- /utils/initParams.m: Configuration parameters for mainLTL, mainPt2Pt, and mainGuided.   
- /env/: Define the environment.   
- /sys/: Define the system dynamics.    

### References
The papers below detail the theory behind LtlOpt. If you use LtlOpt in your research, please cite a relevant paper:   
- Optimization-based trajectory generation with linear temporal logic specifications.  
  E. M. Wolff, U. Topcu, and R. M. Murray. 
  International Conference on Robotics and Automation (ICRA), 2014.
- Optimal control of nonlinear systems with temporal logic specifications.  
  E. M. Wolff and R. M. Murray. 
  International Symposium on Robotics Research (ISRR), 2013.
- Automaton-guided controller synthesis for nonlinear systems with temporal logic.  
  E. M. Wolff, U. Topcu, and R. M. Murray.
  International Conference on Intelligent Robots and Systems (IROS), 2013.

**Author**: Eric Wolff   
**Email**: ewolff@caltech.edu   
**License**: BSD 3-Clause (http://opensource.org/licenses/BSD-3-Clause), see LICENSE for details   
**(C)** 2014 California Institute of Technology 
Please email me with comments, bug reports, or feature requests.   
