function F = cstReach(safe, reach, sys, X, N, bigM, blk_safe)
%cstReach Create constrained reachability (reach-avoid) constraints
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details
    
F = [];
nx = sys.nx;
C = sys.C;

%% Safety constraints on X(1),...,X(N-1)
if N > 1
    n_poly = length(safe);

    H = cell(1,n_poly);
    K = cell(1,n_poly);
    M = cell(1,n_poly);
    for i=1:n_poly
        [h,k] = double(safe(i));
        H{i} = h;
        K{i} = k;
        M{i} = bigM*ones(length(k),1);
    end

    % TODO: further vectorize to eliminate 'for' loop
    H = blkdiag(H{:});
    K = vertcat(K{:});
    M = blkdiag(M{:});
    I = kron(ones(n_poly,1),C);

    assert( blk_safe >= 1 )   
    if blk_safe >=2
        fprintf('Blocking safe by %i.\n',blk_safe);
    end

    F = [];
    for t=1:N-1
        if mod(t+blk_safe-1,blk_safe) == 0
            z = binvar(n_poly,1);
            F = [F, sum(z) == 1];
        end
        F = [F, H*I*X((t-1)*nx+1: t*nx) <= K + M*(1 - z) ];
    end
end

%% Reach constraint on X(N)
n_poly = length(reach);  
z = binvar(n_poly,1);

H = cell(1,n_poly);
K = cell(1,n_poly);
M = cell(1,n_poly);
for i=1:n_poly
    [h,k] = double(reach(i));
    H{i} = h;
    K{i} = k;
    M{i} = bigM*ones(length(k),1);
end
H = blkdiag(H{:});
K = vertcat(K{:});
M = blkdiag(M{:});
I = kron(ones(n_poly,1),C);

F = [F, H*I*X((N-1)*nx+1: end) <= K + M*(1 - z), sum(z) == 1];
    
end
