function fSafe = safeAuto(G, C, X, N, bigM, s)
% safeAuto Creates safety constraints w/ automatic prefix/suffix split
%
% :copyright: 2014 by the California Institute of Technology
% :license: BSD 3-Clause, see LICENSE for details

if ~isempty(G)
    % Create safety constraints
    nPoly = length(G);
    z_safe = binvar((N+1)*nPoly, 1);
%         th = sdpvar(N+1,1);

    H_list = cell(nPoly, 1);
    K_list = cell(nPoly, 1);
    M_list = cell(nPoly, 1);
    for i = 1:nPoly
        [H, K] = double(G(i));
        H = H*C;

        % Create constraints at each time step
        H_list{i} = kron(eye(N+1), H);
        K_list{i} = repmat(K, N+1, 1);
        M_list{i} = kron(eye(N+1), bigM*ones(length(K), 1));
    end
    H_safe = vertcat(H_list{:});
    K_safe = vertcat(K_list{:});
    M_safe = blkdiag(M_list{:});

    fSafe = [H_safe*X <= K_safe + M_safe*(1-z_safe)];
%         F_safe = [F_safe,   th <= bigM*s, ...
%                             th >= -bigM*s, ...
%                             th <= P + bigM*(1-s),...
%                             th >= P - bigM*(1-s)];
%         F_safe = [F_safe, th >= 1*ones(N+1,1)];
    fSafe = [fSafe, repmat(eye(N+1), 1, nPoly)*z_safe >= s];
else
    fSafe = [];
end

end
